#
# spec file for package openssl_tpm_engine
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define enginesdir %(pkg-config libcrypto --variable=enginesdir)
Name:           openssl_tpm_engine
Version:        0.4.2
Release:        9.5
Summary:        OpenSSL TPM interface engine plugin
License:        GPL-2.0-or-later
Group:          Productivity/Security
URL:            http://sourceforge.net/projects/trousers
Source0:        https://downloads.sourceforge.net/project/trousers/OpenSSL%%20TPM%%20Engine/%{version}/%{name}-%{version}.tar.gz
Patch0:         openssl_tpm_engine-somodule.patch
Patch1:         0000-openssl-1.1-compatibility-preparation-remove-unneede.patch
Patch2:         0001-openssl-1.1-compatibility-preparation-fix-warnings-a.patch
Patch3:         0002-Explicitly-link-create_tpm_key-against-libcrypto.patch
Patch4:         0003-OpenSSL-1.1-compatibility.patch
Patch5:         0004-automake-add-linker-flags-to-explicitly-build-a-plug.patch
Patch6:         0005-autotools-choose-engine-plugin-name-based-on-OpenSSL.patch
Patch7:         0006-autotools-make-engine-plugin-installation-dir-config.patch
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  trousers-devel
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(openssl)

%description
This package contains a plugin a for OpenSSL which connects it with the
Trusted Platform Module found on newer machines and a create_tpm_key
helper binary to create and extract a TPM key.

%prep
%setup -q
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1

%build
mkdir m4
sh ./bootstrap.sh
%configure --libdir=/%{_lib}
make %{?_smp_mflags}

%install
%make_install
rm %{buildroot}/%{enginesdir}/tpm.la

%files
%license LICENSE
%doc README openssl.cnf.sample
%{_bindir}/create_tpm_key
%dir %{enginesdir}
%{enginesdir}/tpm.so

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jul 20 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
- Use pkgconfig style dependencies
- Update dependencies
- Drop %%check section - tests are not usable in build environment
  (and not run anyways).
* Mon Dec  4 2017 matthias.gerstner@suse.com
- Adjustment to OpenSSL 1.1. I've developed these patches myself, since
  upstream doesn't have anything yet (and it doesn't look like they will
  soon). I'll offer it to upstream by way of a pull request soon.
  By way of these patches the spec file becomes a little bit simpler. The
  enginesdir should be recognized dynamically by the autotools setup via
  pkg-config now. Code and spec should still be able to build against OpenSSL
  1.0 as well.
  0000-openssl-1.1-compatibility-preparation-remove-unneede.patch
  0001-openssl-1.1-compatibility-preparation-fix-warnings-a.patch
  0002-Explicitly-link-create_tpm_key-against-libcrypto.patch
  0003-OpenSSL-1.1-compatibility.patch
  0004-automake-add-linker-flags-to-explicitly-build-a-plug.patch
  0005-autotools-choose-engine-plugin-name-based-on-OpenSSL.patch
  0006-autotools-make-engine-plugin-installation-dir-config.patch
* Thu May  7 2015 dimstar@opensuse.org
- Use the upstream provided bootstrap to make a full cycle.
  Otherwise we might end up with version conflicts between used
  tools.
* Fri Nov  2 2012 meissner@suse.com
- updated to 0.4.2
  - license adjustments
  - allow TPM migration keys
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Sep  5 2011 crrodriguez@opensuse.org
- Fix build with no-add-needed
- engines currently live in %%/{_lib}/engines
* Fri Feb 20 2009 meissner@suse.de
- do not create unnecessary symlinks of the engine module
* Tue Jul 29 2008 meissner@suse.de
- new package, version 0.4.1
  TPM (trusted platform module) engine plugin for the OpenSSL library
  and a create_tpm_key helper binary.
  FATE#304388, FATE#304221
